@@ -207,14 +207,12 @@ def list_jobs(state):
 
     $ disco job list
 
-    Status Decription: \n
+    Status Description: \n
 
-    Deleted\t The job failed\n\r
-    Done\t The job is done\n
+    Success\t The job is successful\n
     Failed\t The job failed\n
-    Listed\t The job is queued\n
-    Unknown\t The job has no status\n
-    Working\t The job is working\n
+    Queued\t The job is queued\n
+    Running\t The job is running\n
     """
 
     if not verify_logged_in():
@@ -387,7 +385,7 @@ def display_job(job, job_status=None):
         info_message(f"Created job with id {job}")
     elif job_status == JobStatus.failed:
         error_message(f"Job {job} failed")
-    elif job_status == JobStatus.done:
+    elif job_status == JobStatus.success:
         success_message(f"Job {job} finished successfully")
     else:
         info_message(f"Created job with id {job}")
