@@ -40,7 +40,7 @@ class TestJobCommands(BaseTest):
             assert result.exit_code == 0
             list_jobs_mock.assert_called()
             is_logged_in_mock.assert_called()
-            assert output_message_includes(result, '| 5d66595208edfa000a250dda | Cool Humor       | Done     |')
+            assert output_message_includes(result, '| 5d66595208edfa000a250dda | Cool Humor       | Success  |')
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
     @patch('disco.Job.list_jobs')
@@ -65,7 +65,7 @@ class TestJobCommands(BaseTest):
         result = runner.invoke(cli, ['job', 'view', 'job_id'])
         get_details_mock.assert_called_once()
         assert result.exit_code == 0
-        assert output_message_includes(result, "Status: Done")
+        assert output_message_includes(result, "Status: Success")
         assert output_message_includes(result, "Name: dsfgfdsgs")
         assert output_message_includes(result, "failed: 1")
 
@@ -94,7 +94,7 @@ class TestJobCommands(BaseTest):
         result = runner.invoke(cli, ['job', 'view', 'job_id'])
         get_details_mock.assert_called_once()
         assert result.exit_code == 0
-        assert output_message_includes(result, "Status: Done (stopped)")
+        assert output_message_includes(result, f"Status: {JobStatus.success.value} (stopped)")
         assert output_message_includes(result, "Name: job to cancel")
         assert output_message_includes(result, "success: 2")
         assert output_message_includes(result, "stopped: 2")
@@ -811,7 +811,7 @@ class TestJobCommands(BaseTest):
         path_is_dir_mock.return_value = False
         job_create_mock.return_value = Job("job_id")
         asset_upload_mock.return_value = 'file_id'
-        wait_for_finish_mock.return_value = JobStatus.done
+        wait_for_finish_mock.return_value = JobStatus.success
         runner = CliRunner()
         with runner.isolated_filesystem():
             with open('script_file.py', 'w') as f:
