@@ -112,7 +112,7 @@ class TestJobsLive(BaseTest):
         print(f'job {job.job_id} finished!')
 
         job.wait_for_finish(interval=10, timeout=LIVE_TESTS_TIMEOUT_SECONDS)
-        assert job.get_status() == JobStatus.done
+        assert job.get_status() == JobStatus.success
 
         job.archive()
 
@@ -159,7 +159,7 @@ class TestJobsLive(BaseTest):
         print(f'Waiting for job {job.job_id} to finish...')
 
         job.wait_for_finish(interval=10, timeout=LIVE_TESTS_TIMEOUT_SECONDS)
-        assert job.get_status() == JobStatus.done
+        assert job.get_status() == JobStatus.success
 
         print(f'job {job.job_id} finished!')
 
